// ************ Andrew/Oct2004 ************
// really just a list of variables
// used by the ActiveX Help control and the popup method
// All popup text should appear here for easy editing
//
// Modified: 15/06/2005

popFont="Arial,9,,ITALIC"

strPasswordPolicies="     . , ,    ,     ,    &rarr;&rarr;  "

strBruce="   (Applied Cryptography)   ,   Blowfish,       Counterpane Internet Security."

strSpecialChars="   `   ~   !   @   #   $   %   ^   &   *   (   )   _   +   -   =   |   }   {   [   ]   <   >   ?   /   \   :   ;   |   "

strMasterPassword="   -  ,      Password Safe."

strPopText1=""

strExternalFile=" :  Password Safe  1.x;   (.txt)   .        ,       ."

strHexDec=" :\n 0  1  2  3  4  5  6  7  8  9  a  b  c  d  e  f"
